==> duck_f1-0.1.0.tar.gz: duck_f1-0.1.0/src/duck_f1/transform/models/intermediate/docs/intermediate__tables.md <==
{% docs tbl_int_driver__season_championship %}
Round by round statistics for each driver about their championship classification
{% enddocs %}
---
{% docs tbl_int_driver__season_race_results %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---
{% docs tbl_int_drivers %}
List of all drivers from ergast and live timing
{% enddocs %}
---
{% docs tbl_int_live_timing__car__positions %}
Telemetry stream for the car positions
{% enddocs %}
---
{% docs tbl_int_live_timing__car__telemetry %}
Telemetry stream for the car rpm, speed, gear, throttle position, brake position and drs status
{% enddocs %}
---
{% docs tbl_int_live_timing__drivers %}
List drivers that participated in an event session
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__sector_times %}
Pivot of the sector times for each lap
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__speed_traps %}
Pivot of the speed traps for each lap
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__timing %}
Registered time for each laps in a session
{% enddocs %}
---
{% docs tbl_int_live_timing__tyre_stints %}
Stint tyre information for each drivers
{% enddocs %}
---
{% docs tbl_int_season__world_champion %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---
{% docs tbl_int_standings__constructors %}
Round by round statistics for the race performance of each constructors
{% enddocs %}
---
{% docs tbl_int_standings__drivers %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---

==> duck_f1-0.2.0.tar.gz: duck_f1-0.2.0/src/duck_f1/transform/models/intermediate/docs/intermediate__tables.md <==
{% docs tbl_int_driver__season_championship %}
Round by round statistics for each driver about their championship classification
{% enddocs %}
---
{% docs tbl_int_driver__season_race_results %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---
{% docs tbl_int_drivers %}
List of all drivers from ergast and live timing
{% enddocs %}
---
{% docs tbl_int_live_timing__car__positions %}
Telemetry stream for the car positions
{% enddocs %}
---
{% docs tbl_int_live_timing__car__telemetry %}
Telemetry stream for the car rpm, speed, gear, throttle position, brake position and drs status
{% enddocs %}
---
{% docs tbl_int_live_timing__drivers %}
List drivers that participated in an event session
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__sector_times %}
Pivot of the sector times for each lap
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__speed_traps %}
Pivot of the speed traps for each lap
{% enddocs %}
---
{% docs tbl_int_live_timing__lap__timing %}
Registered time for each laps in a session
{% enddocs %}
---
{% docs tbl_int_live_timing__tyre_stints %}
Stint tyre information for each drivers
{% enddocs %}
---
{% docs tbl_int_season__world_champions %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---
{% docs tbl_int_standings__constructors %}
Round by round statistics for the race performance of each constructors
{% enddocs %}
---
{% docs tbl_int_standings__drivers %}
Round by round statistics for the race performance of each driver
{% enddocs %}
---
